%define _unpackaged_files_terminate_build 1

%define oname ffc

Name: python3-module-%oname
Epoch: 1
Version: 2019.1.0
Release: alt2
Summary: Compiler for finite element variational forms
Group: Development/Tools
License: LGPLv3+
URL: https://fenicsproject.org/

BuildArch: noarch

# https://bitbucket.org/fenics-project/ffc.git
Source: %name-%version.tar
# http://www.fenics.org/pub/documents/ffc/ffc-user-manual/ffc-user-manual.pdf
Source1: ffc-user-manual.pdf
Patch0: 0001-Add-compatibility-against-Pytest-6.0.patch

BuildRequires(pre): rpm-build-python3
BuildRequires: python3-devel python3-module-setuptools
BuildRequires: libnumpy-py3-devel
BuildRequires: python3-module-fiat
BuildRequires: python3-module-ufl
# test dependencies
BuildRequires: python3-module-pytest
BuildRequires: cmake gcc-c++

Provides: %oname = %EVR
Obsoletes: %oname < %EVR

%add_python3_req_skip coffee.base coffee.plan coffee.visitors
%add_python3_req_skip tsfc.driver tsfc.kernel_interface.ufc

%description
FFC is a compiler for finite element variational forms. From a high-level
description of the form, it generates efficient low-level C++ code that
can be used to assemble the corresponding discrete operator (tensor). In
particular, a bilinear form may be assembled into a matrix and a linear
form may be assembled into a vector.

FFC may be used either from the command line (by invoking the 'ffc' command)
or as a Python module ('import ffc').

FFC is part of the FEniCS project (www.fenics.org) and functions as a
just-in-time (JIT) compiler for DOLFIN.

%package doc
Summary: User manual for FFC
Group: Development/Documentation
BuildArch: noarch
Requires: %name = %EVR

%description doc
FFC is a compiler for finite element variational forms. From a high-level
description of the form, it generates efficient low-level C++ code that
can be used to assemble the corresponding discrete operator (tensor). In
particular, a bilinear form may be assembled into a matrix and a linear
form may be assembled into a vector.

This package contains user manual for UFL (Unified Form Language).

%prep
%setup
%autopatch -p1

%build
%python3_build

%install
%python3_build_install --optimize=2

install -d %buildroot%_docdir/%name
install -p -m644 %SOURCE1 %buildroot%_docdir/%name

%check
# test_evaluate.py uses libs/ffc-factory, which is currently ignored
# test_elements.py uses dijitso
python3 -m pytest -v test/ --ignore=test/unit/ufc/finite_element/test_evaluate.py --ignore=test/unit/misc/test_elements.py

%files
%doc COPYING COPYING.LESSER LICENSE
%doc AUTHORS ChangeLog.* README.rst
%_bindir/*
%_man1dir/*
%python3_sitelibdir/*

%files doc
%_docdir/%name
%doc demo

%changelog
* Wed Aug 05 2020 Stanislav Levin <slev@altlinux.org> 1:2019.1.0-alt2
- Fixed FTBFS(new Pytest 6).

* Thu Jul 09 2020 Aleksei Nikiforov <darktemplar@altlinux.org> 1:2019.1.0-alt1
- Updated to upstream version 2019.1.0.
- Switched to python-3.

* Tue Jun 07 2016 Ivan Zakharyaschev <imz@altlinux.org> 1:1.6.0-alt1.dev.git20150430.1
- (AUTO) subst_x86_64.

* Sat May 02 2015 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.6.0-alt1.dev.git20150430
- Version 1.6.0dev

* Mon Nov 03 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.4.0-alt1.git20141022
- Version 1.4.0

* Thu May 08 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.3.0-alt2.git20140430
- Obsoletes: python-module-ufc

* Wed May 07 2014 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.3.0-alt1.git20140430
- Version 1.3.0

* Thu Oct 24 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.2.0-alt2.git20131007
- New snapshot

* Mon Jun 17 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.2.0-alt2.git20130429
- Rebuilt with updated NumPy

* Tue May 07 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.2.0-alt1.git20130429
- Version 1.2.0

* Thu Jan 31 2013 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.1.0-alt1.bzr20130129
- Version 1.1.0

* Mon Oct 15 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.0.0-alt1.bzr20120910
- New snapshot

* Mon Aug 13 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.0.0-alt1.bzr20120530
- New snapshot

* Sun May 13 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.0.0-alt1.bzr20120507
- New snapshot

* Tue Jan 17 2012 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1:1.0.0-alt1.bzr20111207
- Version 1.0.0

* Tue Dec 06 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 1.0.rc1-alt1.bzr20111130
- Version 1.0.rc1

* Thu Oct 27 2011 Vitaly Kuznetsov <vitty@altlinux.ru> 0.9.10-alt1.bzr20110708.2
- Rebuild with Python-2.7

* Thu Oct 27 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.10-alt1.bzr20110708.1
- Rebuilt with updated NumPy

* Wed Aug 03 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.10-alt1.bzr20110708
- Version 0.9.10

* Fri Apr 15 2011 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.9-alt1.bzr20110404
- Version 0.9.9

* Tue Nov 23 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.4-alt1.bzr20101122
- Version 0.9.4

* Tue Aug 10 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.3-alt1.bzr20100724
- Version 0.9.3

* Wed Jun 16 2010 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.9.2-alt1.bzr20100615
- Version 0.9.2

* Wed Dec 09 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.7.1-alt3.bzr20091204
- Version 0.7.1

* Tue Nov 10 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.6.2-alt2.hg20090831.1
- Rebuilt with python 2.6

* Mon Aug 31 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.6.2-alt2.hg20090831
- Snapshot 20090831

* Tue Jul 21 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.6.2-alt2.hg20090819
- New snapshot

* Fri Apr 24 2009 Eugeny A. Rostovtsev (REAL) <real at altlinux.org> 0.6.2-alt1
- Initial build for Sisyphus

